@@ -2,12 +2,10 @@
 #code based on Semmens et al 2009
 #see IsotopeR instructions.doc for details on running the model.
 #see Hopkins and Ferguson 2011 for details on the model structure.
-#Jake Ferguson: last updated 4/25/12
+#Jake Ferguson: last updated 7/1/11
 
-IsoWrapper <- function(Mixtures="Necessary File", Sources="Necessary File", Concentrations="Optional File", Measurement.Error="Optional File", Discrimination.Error="Optional File", Digestibility.Factor="Optional File", output.name="SampleOutput.Rdata", mcmc.chains=3, mcmc.burn=1e3, mcmc.chainLength=1e3, mcmc.thin=10, plot.mixing.observations=TRUE, plot.mixing.estimates=TRUE, plot.dietary.source.contributions=TRUE) {
+IsoWrapper <- function(Mixtures="Necessary File", Sources="Necessary File", Concentrations="Optional File", Measurement.Error="Optional File", Discrimination.Error="Optional File", Digestibility.Factor="Optional File", output.name="SampleOutput.Rdata", mcmc.chains=3, mcmc.burn=1e3, mcmc.chainLength=1e3, mcmc.thin=10, plot.observations=TRUE,  plot.mixing.estimates=TRUE, plot.dietary.source.contributions=TRUE, color.plots=TRUE) {
     require(runjags)
-#     source('IsotopeRModelsNoGroups.R')
-#     source('IsotopeRModelsGroups.R')
     
     mcmc.chainLength    <- as.integer(mcmc.chainLength+mcmc.burn) #total number of iterations per chain (includes burnin)
 
@@ -22,15 +20,15 @@ IsoWrapper <- function(Mixtures="Necessary File", Sources="Necessary File", Conc
     nodiscrim.flag = 0
     nodigest.flag=0
     
-    #reads in the files
+    #reads in the files               
     X           <- try(as.matrix(read.table(Mixtures, sep='\t', header=TRUE)), silent=TRUE) #mixture data file
     if(class(X) == 'try-error') {stop("Mixture file not found")}
     if(dim(X)[2] == 1) {
         X           <- as.matrix(read.table(Mixtures, sep=',', header=TRUE)) #mixture data file
     }
-        
+    
     sources     <- try((read.table(Sources,sep='\t',header=TRUE)), silent=TRUE) #source data
-    if(class(sources) == 'try-error') {stop("Source file not found")}
+	if(class(sources) == 'try-error') {stop("Source file not found")}
     if(dim(sources)[2] == 1) { 
         sources     <- (read.table(Sources,sep=',',header=TRUE)) #source data
     }
@@ -86,7 +84,6 @@ IsoWrapper <- function(Mixtures="Necessary File", Sources="Necessary File", Conc
         }
     }
     
-
     #extract useful info from the read in data to pass to JAGS
     N       <- dim(X)[1] #number of individuals in the sample
     num.iso     <- dim(X)[2]-2 #number of isotopes in the sample
@@ -99,6 +96,7 @@ IsoWrapper <- function(Mixtures="Necessary File", Sources="Necessary File", Conc
 		groupnum.mat[i,2] <- max(which(X[,num.iso+1]==i))
 	}
 	#determine the proper model to run
+
     if(file.flag == "") { 
 		if(num.groups ==1) { curr.model <- IsotopeRfull} else {
 		curr.model <- IsotopeRfullgroup}
@@ -131,6 +129,8 @@ IsoWrapper <- function(Mixtures="Necessary File", Sources="Necessary File", Conc
 		if(num.groups == 1) { curr.model <- IsotopeRnomenodiscrim } else {
 		curr.model <- IsotopeRnomenodiscrimgroup }
 	}
+print(file.flag)
+print(num.groups)
 
 	#prior diet proportions
     alpha <- rep(1,num.sources)/num.sources
@@ -225,10 +225,6 @@ IsoWrapper <- function(Mixtures="Necessary File", Sources="Necessary File", Conc
 			}
 			source.counter <- source.counter + 1
 		}
-            
-#         } else {
-# 			stop('Error in Concentration Dependence Code')
-# 		}
     }
 
 	#builds discrimination variation matrices (added to estimators of the standard deviation in order to account for discrimination variation)
@@ -240,10 +236,8 @@ IsoWrapper <- function(Mixtures="Necessary File", Sources="Necessary File", Conc
     #gets number of individual observations
     num.inds <- nlevels(as.factor(X[,4]))
     ind.counts <- vector('numeric',num.inds)
-#     ind.counts.index    <- matrix(NA, num.inds, dim(X)[1]-num.inds+1)
     for(i in 1:num.inds) {
         ind.counts[i] <- length(which(i == X[,4]))
-#         ind.counts.index[i,] <- which(X[,4] == i)
     }
     #individual observation matrix
     ind.array <- array(NA,c(num.iso,num.inds,max(ind.counts)))
@@ -258,8 +252,9 @@ IsoWrapper <- function(Mixtures="Necessary File", Sources="Necessary File", Conc
         jags.rem    <- which( names(jags.dump)  == 'cd.mat' |  names(jags.dump)  == 'dmu.prior.mu' |  names(jags.dump)  == 'dmu.prior.tau' |  names(jags.dump)  == 'subcd.samples' |  names(jags.dump)  == 'subcd.vec')
         jags.dump <- jags.dump[-jags.rem]
         
-       jags.rem <- which(jags.params == "mu.conc") 
+       jags.rem <- which(jags.params == "mu.conc" | jags.params=="sd.conc") 
 	   jags.params <- jags.params[-jags.rem]
+	
     }
     if(nome.flag) {
         jags.rem    <- which(names(jags.dump)  == 'Z' | names(jags.dump) == 'muz' | names(jags.dump) == 'tauZ' | names(jags.dump)== 'Nz')
@@ -287,31 +282,61 @@ IsoWrapper <- function(Mixtures="Necessary File", Sources="Necessary File", Conc
 	r.est <- jags.out$psrf$psrf[,1]
 	jags.output.mat <- cbind(jags.out$summary$statistics[,1:2], jags.out$summary$quantiles, r.est)
     
-	print(jags.output.mat)
+	save(jags.out, jags.output.mat, X, sources, nome.flag, num.sources, num.iso, mcmc.chains, N, num.groups, file=output.name)
 	
-    save(jags.out, X, file=output.name) #save image file with all the info from the MCMC 
     write.table(jags.output.mat, file=paste(strsplit(output.name, ".Rdata")[[1]],'.txt',sep=''))
-    if(plot.mixing.observations) {
+    if(plot.observations) {
         dev.new()
-        if(num.sources == 3) { Tri.plots(jags.out,X,plot.ind=TRUE, me.flag=!nome.flag) } else {
-        if(num.sources == 2) { Bi.plots(jags.out,X,plot.ind=TRUE, me.flag=!nome.flag) } else {stop("No plotting method available for this many isotopes")}
-        }
+		Tri.plots(jags.out, X, sources=sources, plot.ind=TRUE, me.flag=!nome.flag, color.plots=color.plots)
     }
 
     if(plot.mixing.estimates) {
-        dev.new()
-        if(num.sources == 3) { Tri.plots(jags.out, X, plot.mix=TRUE, me.flag=!nome.flag) } else {
-        if(num.sources == 2) { Bi.plots(jags.out, X,  plot.mix=TRUE, me.flag=!nome.flag) } else {stop("No plotting method available for this many isotopes")}
+        
+        if(num.sources == 3 & num.iso==2) {dev.new(); Tri.plots(jags.1=jags.out, X=X, sources=sources, plot.mix=TRUE, me.flag=!nome.flag, color.plots=color.plots) } else {
+        if(num.sources == 2 & num.iso==2) {dev.new(); Bi.plots(jags.out, X,  sources=sources, plot.mix=TRUE, me.flag=!nome.flag, color.plots=color.plots) } else {warning("No plotting method available for isotope/source combination")}
         }    
     }
     
     if(plot.dietary.source.contributions) {
         dev.new()
-        curves.plot(jags.1=jags.out, num.sources=num.sources, num.chains=mcmc.chains, color=TRUE, individuals=N,  xlab.vec=unique(sources[,num.iso+1]), num.groups=num.groups)
+        curves.plot(jags.1=jags.out, num.sources=num.sources, num.chains=mcmc.chains, color=color.plots, individuals=N,  xlab.vec=unique(sources[,num.iso+1]), num.groups=num.groups)
+    }
+	print(jags.output.mat)
+
+}
+
+##load previously run data and outputs graphs
+load.prev.func <- function(file.name="SampleOutput.Rdata", plot.observations=TRUE, plot.mixing.estimates=TRUE, plot.dietary.source.contributions=TRUE, color.plots=TRUE) {
+
+	jags.out=NA
+	X=NA
+	sources=NA
+	nome.flag=NA
+	num.iso=NA
+	num.sources=NA
+	mcmc.chains=NA
+	N=NA
+	num.groups=NA
+	jags.output.mat=NA
+	load(file=file.name)
+	if(any(is.na(c(jags.out, X, sources, nome.flag, num.iso, num.sources, mcmc.chains, N, num.groups, jags.output.mat)))) {stop(".Rdata file error")}
+	
+	if(plot.observations) {
+		dev.new()
+		Tri.plots(jags.out, X, sources=sources, plot.ind=TRUE, me.flag=!nome.flag, color.plots=color.plots) 
     }
 
-#     return(jags.out)
-
+    if(plot.mixing.estimates) {
+        if(num.iso == 2 & num.sources==3) {dev.new(); Tri.plots(jags.1=jags.out, X=X, sources=sources, plot.mix=TRUE, me.flag=!nome.flag) } else {
+        if(num.iso == 2 & num.sources==2) {dev.new(); Bi.plots(jags.out, X,  sources=sources, plot.mix=TRUE, me.flag=!nome.flag) } else {warning("No mixing plot available for this isotope/source combination")}
+        }    
+    }
+    
+    if(plot.dietary.source.contributions) {
+        dev.new()
+        curves.plot(jags.1=jags.out, num.sources=num.sources, num.chains=mcmc.chains, color=color.plots, individuals=N,  xlab.vec=unique(sources[,num.iso+1]), num.groups=num.groups)
+    }
+    print(jags.output.mat)
 }
 
 IsotopeR    <- function() {
@@ -319,9 +344,15 @@ IsotopeR    <- function() {
     require(fgui) #used to run JAGS from R
 
     if(interactive()) {
-        output <- guiv(IsoWrapper, argFilter = list(Mixtures="{{} {.csv}}", Sources="{{} {.csv}}", Concentrations="{{} {.csv}}", Measurement.Error="{{} {.csv}}",   Discrimination.Error="{{} {.csv}}", Digestibility.Factor="{{} {.csv}}", output.name="{{} {.Rdata}}"), argText = list(mcmc.chains="number of chains", mcmc.burn="MCMC burnin", mcmc.chainLength="MCMC runs", mcmc.thin="thinning rate"), argOption = list(plot.mixing.observations=c("TRUE","FALSE"), plot.dietary.source.contributions= c("TRUE", "FALSE"), plot.mixing.estimates=c('TRUE','FALSE')), closeOnExec=TRUE, title="IsotopeR v0.2.1", exec="Run IsotopeR", helpsFunc="IsoWrapper")
+		fguiWindow( basicMenu=FALSE, title="IsotopeR", text="Please choose an option from the Analysis menu." )
+		win <- mgui(IsoWrapper, argFilter = list(Mixtures="{{} {.csv}}", Sources="{{} {.csv}}", Concentrations="{{} {.csv}}", Measurement.Error="{{} {.csv}}",   Discrimination.Error="{{} {.csv}}", Digestibility.Factor="{{} {.csv}}"), argText = list(mcmc.chains="number of chains", mcmc.burn="MCMC burnin", mcmc.chainLength="MCMC runs", mcmc.thin="thinning rate", output.name="Output file"), argOption = list(plot.observations=c("TRUE","FALSE"), plot.dietary.source.contributions= c("TRUE", "FALSE"), plot.mixing.estimates=c('TRUE','FALSE'), color.plots=c("TRUE", "FALSE")), closeOnExec=TRUE, title=c("Analysis","New Run"), exec="Run IsotopeR", helpsFunc="IsoWrapper", output=NULL)
+		
+		win <- mgui(load.prev.func, title=c("Analysis","Load Previous Run"), argFilter= list(file.name="{{} {.Rdata}}"), argOption = list(plot.observations=c("TRUE","FALSE"), plot.dietary.source.contributions= c("TRUE", "FALSE"), plot.mixing.estimates=c('TRUE','FALSE'), color.plots=c("TRUE", "FALSE")), closeOnExec=TRUE , exec="Plot", output=NULL, helpsFunc="IsoWrapper")
+# 		print(win)
+		
     }
 
     options(warn=0)
 
 }
+
